@@ -18,7 +18,7 @@
 #ifndef PYCOMPLETIONTEST_H
 #define PYCOMPLETIONTEST_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include <language/editor/cursorinrevision.h>
 #include <language/codecompletion/codecompletioncontext.h>
@@ -29,14 +29,24 @@ using namespace KDevelop;
 
 namespace Python {
 
+struct CompletionParameters {
+    DUContextPointer contextAtCursor;
+    QString snip;
+    QString remaining;
+    CursorInRevision cursorAt;
+};
+
 class PyCompletionTest : public QObject
 {
     Q_OBJECT
     public:
-        explicit PyCompletionTest(QObject* parent = 0);
+        explicit PyCompletionTest(QObject* parent = nullptr);
         void initShell();
         
         const QList<CompletionTreeItem*> invokeCompletionOn(const QString& initCode, const QString& invokeCode);
+        const CompletionParameters prepareCompletion(const QString& initCode, const QString& invokeCode);
+        const QList<CompletionTreeItem*> runCompletion(const CompletionParameters data);
+
         bool containsItemForDeclarationNamed(const QList< CompletionTreeItem* > items, QString itemName);
         // convenience function
         bool declarationInCompletionList(const QString& initCode, const QString& invokeCode, QString itemName);
@@ -72,9 +82,21 @@ class PyCompletionTest : public QObject
         void testAutoBrackets();
         void testAddImportCompletion();
         void testAddImportCompletion_data();
+        void testFunctionDeclarationCompletion();
+        void testFunctionDeclarationCompletion_data();
+        void testCompletionScopes();
+        void testCompletionScopes_data();
+        void testStringFormattingCompletion();
+        void testStringFormattingCompletion_data();
+        void testStringFormatter();
+        void testStringFormatter_data();
+        // benchmarks
+        void completionBenchTest();
+        void completionBenchTest_data();
     private:
         QList<CompletionTreeItemPointer> m_ptrs;
+
 };
 
 }
-#endif
\ No newline at end of file
+#endif
