@@ -17,8 +17,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>. *
  ************************************************************************/
 
-#ifndef KCM_PY_DOCFILES_H
-#define KCM_PY_DOCFILES_H
+#ifndef PY_KCM_DOCFILES_H
+#define PY_KCM_DOCFILES_H
 
 #include <interfaces/configpage.h>
 
@@ -29,15 +29,17 @@ class DocfilesKCModule : public KDevelop::ConfigPage
 Q_OBJECT
 public:
     DocfilesKCModule(KDevelop::IPlugin* plugin, QWidget* parent);
-    virtual ~DocfilesKCModule();
+    ~DocfilesKCModule() override;
 
-    virtual QString name() const override;
-    virtual QString fullName() const override;
-    virtual QIcon icon() const override;
+    KDevelop::ConfigPage::ConfigPageType configPageType() const override;
 
-    virtual void apply() override;
-    virtual void reset() override;
-    virtual void defaults() override;
+    QString name() const override;
+    QString fullName() const override;
+    QIcon icon() const override;
+
+    void apply() override;
+    void reset() override;
+    void defaults() override;
 
 private:
     DocfileManagerWidget* managerWidget;
